@@ -1,16 +1,18 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
+"""Annotation 相关"""
+
 import datetime
 from typing import List, Optional
 from xml.etree.ElementTree import Element
-from Annotations2Sub.flag import Flags
 
 from Annotations2Sub.Color import Alpha, Color
 from Annotations2Sub.internationalization import _
+from Annotations2Sub.flag import Flags
 
-# 兼容 Python3.6
-# Python3.6 的 typing 没有 Literal
+# 兼容 Python3.6, 3.7
+# Python3.6, 3.7 的 typing 没有 Literal
 try:
     from typing import Literal  # type: ignore
 except:
@@ -87,12 +89,14 @@ def Parse(tree: Element) -> List[Annotation]:
 
     # 在在此之前(f20f9f fixbugs) XML 树就直接转换为 Event 了
     # 代码随着时间推移变得很糟
-    # 幸好当初没傻到直接吐出来字符串
+    # 幸好当初没傻到直接吐出来字符串, youtube-ass 就是这么干的
 
     # 在这之前我还想过从树到 Event 是一个完美的管线
     # 然后遇到了 None 和 多个 Event
     # 还是吐出来一个 List 比较好
 
+    # 我想测试这些内部函数
+    # 但是无法访问内部函数
     def ParseAnnotationAlpha(s: str) -> Alpha:
         """
         解析 Annotation 的透明度
@@ -119,6 +123,7 @@ def Parse(tree: Element) -> List[Annotation]:
 
     def MakeSureStr(s: Optional[str]) -> str:
         """确保输入的是字符串"""
+
         # 这个是用来应付类型注释了, 我觉得在输入确定的环境里做类型检查没有必要
         if isinstance(s, str):
             return str(s)
@@ -126,6 +131,7 @@ def Parse(tree: Element) -> List[Annotation]:
 
     def ParseAnnotation(each: Element) -> Optional[Annotation]:
         """解析 Annotation"""
+
         # 致谢: https://github.com/nirbheek/youtube-ass
         # 致谢: https://github.com/isaackd/annotationlib
         annotation = Annotation()
@@ -209,12 +215,12 @@ def Parse(tree: Element) -> List[Annotation]:
                 print(_("{} 不显示, 跳过").format(annotation.id))
             return None
 
-        # 其实这些字符串可以直接在 SSA 上用的, 但是不知道为什么之前(f20f9f fixbugs)来回转换了两次
+        # 其实这些字符串可以直接在 SSA 上用的, 但是不知道为什么之前来回转换了两次
         # 那些代码已经是两年前写的了
         # 我也忘了
         try:
             annotation.timeStart = datetime.datetime.strptime(Start, "%H:%M:%S.%f")
-            # 在这之前(f20f9f fixbugs)我会在这里 ↓ 加两个空格与上面对齐, 但是 black 好像不太喜欢
+            # 在这之前我会在这里 ↓ 加两个空格与上面对齐, 但是 black 好像不太喜欢
             annotation.timeEnd = datetime.datetime.strptime(End, "%H:%M:%S.%f")
         except:
             annotation.timeStart = datetime.datetime.strptime(Start, "%M:%S.%f")
@@ -229,7 +235,7 @@ def Parse(tree: Element) -> List[Annotation]:
         sx = Segment[0].get("sx")
         sy = Segment[0].get("sy")
 
-        # 在之前(f20f9f fixbugs) 用的是 if x is not None:, 其他人用的是 if x:
+        # 在之前用的是 if x is not None:, 其他人有用 if x:
         # 我觉得 if x: 用在布尔值上比较好
         # is not 就算了
         # 所以用了 if x != None:
