@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__version__ = "0.1.36"
+__version__ = "0.1.37"
 
 """
 Annotations2Sub, 一个能把 Youtube 注释转换成 Sub Station Alpha V4 字幕文件的脚本
@@ -26,6 +26,7 @@ Annotations2Sub, 一个能把 Youtube 注释转换成 Sub Station Alpha V4 字
 │                │            │        │            │             │
 └────────────────┘            └────────┘            └─────────────┘
 
+https://www.youtube.com/channel/UCe4QujtMby3h6dge1eYaPig
 在 2019 年的某一天, 我在 Youtube 听歌, 发现字幕没了.
 从评论区我得知: "從 2019 年 1 月 15 日起，我們將不再對觀眾顯示現有的註解。所有的現有註解都將移除。"
 我当即破口大骂谷歌.
@@ -46,18 +47,30 @@ Annotations2Sub, 一个能把 Youtube 注释转换成 Sub Station Alpha V4 字
 之后(a64995 庆祝一下), 使用了 "绘图模式" 实现了 "popup" 样式
 在 https://invidious.io/ 和 FFmpeg 的帮助下, 实现了简单的视频预览
 再之后, 脚本逐步完善, 完成了 https://www.bilibili.com/video/BV1Ff4y1t7Dj
+但是还是有些遗憾
+---以下是有类似问题的视频，以制表符分隔---
+videoId	title
+g-0i6MOh7n0	志方あきこ - ラ・シェール 中文字幕(Chinese Translation)
+aaLI3ErnHQg	志方あきこ - EXEC_HARMONIUS/. 中文字幕(Chinese Translation)
+sgeXEwVWnpI	志方あきこ - EXEC_over.METHOD_SUBLIMATION/. ~omness chs ciel sos infel  中文字幕(Chinese Translation)
+R4CqsDTnT60	志方あきこ - Ec Tisia ～Tarifa～ 中文字幕(Chinese Translation)
+---以上是有类似问题的视频，以制表符分隔---
+说实话我不想实现恶心的 CSS 定位
+更何况 annotationlib 都没有正确实现定位
 
 ---
 
 作为我的第一个代码, 我一直想让其趋于完美.
 首先想的是参考 https://github.com/isaackd/annotationlib (致谢), 将 Annotation 抽成一个简单的结构, 
-与脚本生成器(转换器)解耦, 结果并没有让事情变简单.
-
+与脚本生成器(转换器)解耦, 结果并没有让事情变简单. (这是两年前的事了)
 之后还尝试过实现 speech 样式, 把事情弄得一团糟
-尝试过扔掉 invidious , 发现我简直像个shaberhu
+尝试过扔掉 invidious , 发现我简直像个shaberhu (这是一年前的事)
 只好作罢, 上学去了.
-
+...
 自从 2022 年新年开始我已经半年呆在家里了, 我有了时间一直折腾代码, 我决定再次挑战这个目标.
+首先, 我把我按照写 Go 的经验把脚本拆成了模块, 上传到了 PyPI, 并尝试为其编写单元测试, 并借以此实现了多语言
+然后, 再次尝试将 Annotation 抽成一个简单的结构
+现在, 我尝试对其进行详尽的注释, 到目前为止看起来不错.
 
 ---
 
