@@ -1,11 +1,17 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
+"""程序入口"""
+
 import argparse
 import os
 import re
 import traceback
 import urllib.request
+
+# 我觉得在输入确定的环境下用不着这玩意
+# 不过打包到了 PyPI 也不用像以前那些忌惮第三方库了
+# 不用白不用
 import defusedxml.ElementTree  # type: ignore
 import _thread
 
@@ -19,11 +25,11 @@ from Annotations2Sub.tools import (
     AnnotationsForArchive,
     CheckUrl,
     RedText,
-    VideoForInvidiou,
+    VideoForInvidious,
     YellowText,
 )
 
-
+# 程序入口
 def main():
     parser = argparse.ArgumentParser(
         description=_(
@@ -45,6 +51,7 @@ def main():
         action="store_true",
         help=_("拥抱 libass 的怪癖和特性, 不指定此选项则会适配 xy-vsfilter"),
     )
+    # 虽然把分辨率置为 100, 100 字幕滤镜也能正常定位, 但是显然正确的分辨率更惹字幕滤镜喜欢
     parser.add_argument(
         "-x",
         "--transform-resolution-x",
@@ -61,6 +68,7 @@ def main():
         metavar=100,
         help=_("变换分辨率Y"),
     )
+    # 应该使用非衬线字体, 但是 SSA 不能方便的指定字体家族, 只得出此下策
     parser.add_argument(
         "-f",
         "--font",
@@ -69,6 +77,7 @@ def main():
         metavar=_("Microsoft YaHei"),
         help=_("指定字体"),
     )
+    # 其实我觉得这个选项应该没啥用
     parser.add_argument(
         "-o",
         "--output-path",
@@ -88,18 +97,21 @@ def main():
         metavar="invidious.domain",
         help=_("指定 invidious 实例(https://redirect.invidious.io/)"),
     )
+    # 就是拼接参数执行 mpv
     parser.add_argument(
         "-p",
         "--preview-video",
         action="store_true",
         help=_("预览视频, 需要 mpv(https://mpv.io/) 并指定 invidious 实例"),
     )
+    # 与上面同理
     parser.add_argument(
         "-g",
         "--generate-video",
         action="store_true",
         help=_("生成视频, 需要 FFmpeg(https://ffmpeg.org/) 并指定 invidious 实例)"),
     )
+    # 可能是用来甩锅用的
     parser.add_argument(
         "-u",
         "--unstable",
@@ -112,6 +124,7 @@ def main():
         action="store_true",
         help=_("显示版本号"),
     )
+    # 这个好像不是用来调试用的
     parser.add_argument(
         "-V",
         "--verbose",
@@ -133,8 +146,8 @@ def main():
         Flags.verbose = True
 
     if args.output_path != None:
-        if os.path.isfile(args.output_path):
-            print(RedText(_("转换后文件的输出路径应该指定一个文件夹, 而不是文件")))
+        if os.path.isdir(args.output_path) is False:
+            print(RedText(_("转换后文件的输出路径应该指定一个文件夹")))
             exit(1)
 
     if args.preview_video or args.generate_video:
@@ -145,11 +158,14 @@ def main():
         args.download_for_archive = True
         args.embrace_libass = True
 
+    # 先查一遍
     if args.download_for_archive is False:
         for filePath in args.queue:
+            # 先看看有没有不是文件的
             if os.path.isfile(filePath) is False:
                 print(RedText(_("{} 不是一个文件").format(filePath)))
                 exit(1)
+            # 再看看有没有文件无效的
             try:
                 tree = defusedxml.ElementTree.parse(filePath)
                 count = 0
@@ -165,7 +181,7 @@ def main():
             filePaths.append(filePath)
 
     if args.download_for_archive:
-
+        # 省的网不好不知道
         def CheckNetwork():
             if CheckUrl() is False:
                 print(YellowText(_("您好像无法访问 Google 🤔")))
@@ -174,13 +190,17 @@ def main():
 
         videoIds = []
         for videoId in args.queue:
+            # 还是先查一遍
             if re.match(r"[a-zA-Z0-9_-]{11}", videoId) is None:
-                raise ValueError("Invalid videoId")
+                print(RedText(_("{} 不是一个有效的视频 ID").format(videoId)))
+                exit(1)
             videoIds.append(videoId)
         for videoId in videoIds:
             filePath = f"{videoId}.xml"
             if args.output_path != None:
                 filePath = os.path.join(args.output_path, filePath)
+            # 为了显示个 "下载 ", 我把下载从 AnnotationsForArchive 里拆出来了
+            # 之前就直接下载了, 但是我还是更喜欢输出确定且可控
             url = AnnotationsForArchive(videoId)
             print(_("下载 {}").format(url))
             string = urllib.request.urlopen(url).read().decode("utf-8")
@@ -206,9 +226,12 @@ def main():
     for filePath in filePaths:
         output = filePath + ".ass"
         if args.output_path != None:
+            # 把文件名剥离出来
             fileName = os.path.basename(filePath) + ".ass"
             output = os.path.join(args.output_path, fileName)
 
+        # 从这里开始就是 __init__.py 开头那个流程图
+        # 其实这才是核心功能, 其他的都是有的没的
         with open(filePath, "r", encoding="utf-8") as f:
             string = f.read()
         tree = defusedxml.ElementTree.fromstring(string)
@@ -221,6 +244,8 @@ def main():
         )
         if events == []:
             print(YellowText(_("{} 没有注释被转换").format(filePath)))
+        # Annotation 是无序的
+        # 按时间重新排列字幕(事件), 主要是为了人类可读
         events.sort(key=lambda event: event.Start)
         sub = Sub()
         sub.events.extend(events)
@@ -232,11 +257,13 @@ def main():
         with open(output, "w", encoding="utf-8") as f:
             f.write(subString)
         print(_("保存于: {}").format(output))
+        # 为了下面而准备
         outputs.append(output)
 
     if args.preview_video:
         for output in outputs:
-            video, audio = VideoForInvidiou(videoId, args.invidious_instances)
+            # 从 Invidious 获取视频流和音频流, 并塞给 mpv, FFmpeg
+            video, audio = VideoForInvidious(videoId, args.invidious_instances)
             cmd = rf'mpv "{video}" --audio-file="{audio}" --sub-file="{output}"'
             if Flags.verbose:
                 print(cmd)
@@ -247,7 +274,8 @@ def main():
 
     if args.generate_video:
         for output in outputs:
-            video, audio = VideoForInvidiou(videoId, args.invidious_instances)
+            # 同理
+            video, audio = VideoForInvidious(videoId, args.invidious_instances)
             cmd = rf'ffmpeg -i "{video}" -i "{audio}" -vf "ass={output}" {output}.mp4'
             if Flags.verbose:
                 print(cmd)
